==> mgb-0.5.4.2-de.zip: redirect.php <==
<?
	/*
	MGB 0.5.4.2
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "settings.php";

	if($_GET[id] == "mgb")
		{
		$redirect = "<meta http-equiv='refresh' content='1; URL=http://www.tv-kritik.net/mgb/index.php'>";
		}
	else
		{
		 // Auslesen der URL
         	$sql="SELECT * FROM $db[entrys] WHERE ID=".$_GET[id];
         	$link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
         	$result=mysql_query($sql, $link) or die ("MySQL Fehler");

         	for($i = 0; $i < mysql_num_rows($result); $i++)
         		{
			$eintrag[$i] = mysql_fetch_array($result);
			}

        		for($i = 0; $i < count($eintrag); $i++)
         		{
                 	$redirect = "<meta http-equiv='refresh' content='1; URL=".$eintrag[$i][hp]."'>";
			}
		}

?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $settings['hpname']; ?> - guestbook v.null.fnf by mopzz.de</title>
<meta name="author" content="<? echo $settings['autor']; ?>">
<meta name="keywords" content="<? echo $settings['keywords']; ?>">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4.2  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php
	echo $redirect;
?>
<script type="text/javascript" src="addsmilies.js"></script>
</head>
<body style="background-color:#FFFFFF;">
<span style="color:#000000;font-family:verdana,arial,helvetica,sans-serif;font-size:12px;">One moment please...</span>
</body>
</html>

==> mgb-0.5.4.4-de.zip: redirect.php <==
<?
	/*
	MGB 0.5.4.4
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "settings.php";

	if($_GET[id] == "mgb")
		{
		$redirect = "<meta http-equiv='refresh' content='1; URL=http://www.tv-kritik.net/mgb/index.php'>";
		}
	else
		{
		 // Auslesen der URL
         	$sql="SELECT * FROM $db[entrys] WHERE ID=".$_GET[id];
         	$link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
         	$result=mysql_query($sql, $link) or die ("MySQL Fehler");

         	for($i = 0; $i < mysql_num_rows($result); $i++)
         		{
			$eintrag[$i] = mysql_fetch_array($result);
			}

        		for($i = 0; $i < count($eintrag); $i++)
         		{
                 	$redirect = "<meta http-equiv='refresh' content='1; URL=".$eintrag[$i][hp]."'>";
			}
		}

?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Administration - MGB 0.5.4.4</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<meta name="description" content="Administration des MGB">
<meta name="robots" content="noindex,nofollow">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.4  Copyright 2004-2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php
	echo $redirect;
?>
<script type="text/javascript" src="addsmilies.js"></script>
</head>
<body style="background-color:#FFFFFF;">
<span style="color:#000000;font-family:verdana,arial,helvetica,sans-serif;font-size:12px;">One moment please...</span>
</body>
</html>
